summaryrefslogtreecommitdiff
path: root/indra/llcommon/llheteromap.cpp
diff options
context:
space:
mode:
authorFawrsk <fawrsk@gmail.com>2023-01-07 00:38:12 -0400
committerFawrsk <fawrsk@gmail.com>2023-01-07 00:38:12 -0400
commit9e743c99fb69db5694c388ae33656c62e3fa0b8e (patch)
treec981c998d0439d8bd48ce98123c19de8a9a27753 /indra/llcommon/llheteromap.cpp
parentd0f115ae093e8268da2a3245d6cb2f3bcc544f1c (diff)
Cleanup for loops in llcommon to use C++11 range based for loops
Diffstat (limited to 'indra/llcommon/llheteromap.cpp')
-rw-r--r--indra/llcommon/llheteromap.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/indra/llcommon/llheteromap.cpp b/indra/llcommon/llheteromap.cpp
index 7c19196e0c..4bc29a1736 100644
--- a/indra/llcommon/llheteromap.cpp
+++ b/indra/llcommon/llheteromap.cpp
@@ -22,11 +22,11 @@ LLHeteroMap::~LLHeteroMap()
{
// For each entry in our map, we must call its deleter, which is the only
// record we have of its original type.
- for (TypeMap::iterator mi(mMap.begin()), me(mMap.end()); mi != me; ++mi)
+ for (TypeMap::value_type pair : mMap)
{
- // mi->second is the std::pair; mi->second.first is the void*;
- // mi->second.second points to the deleter function
- (mi->second.second)(mi->second.first);
- mi->second.first = NULL;
+ // pair.second is the std::pair; pair.second.first is the void*;
+ // pair.second.second points to the deleter function
+ (pair.second.second)(pair.second.first);
+ pair.second.first = NULL;
}
}